package com.meas.system.mapper;

import com.meas.system.domain.MeasSpectralRadiation;

import java.util.List;

/**
 * 光谱辐射Mapper接口
 *
 * @author wgk
 * @date 2024-06-13
 */
public interface MeasSpectralRadiationMapper {
    /**
     * 查询光谱辐射
     *
     * @param id 光谱辐射主键
     * @return 光谱辐射
     */
    public MeasSpectralRadiation selectMeasSpectralRadiationById(Long id);

    /**
     * 查询光谱辐射列表
     *
     * @param measSpectralRadiation 光谱辐射
     * @return 光谱辐射集合
     */
    public List<MeasSpectralRadiation> selectMeasSpectralRadiationList(MeasSpectralRadiation measSpectralRadiation);

    /**
     * 新增光谱辐射
     *
     * @param measSpectralRadiation 光谱辐射
     * @return 结果
     */
    public int insertMeasSpectralRadiation(MeasSpectralRadiation measSpectralRadiation);

    /**
     * 修改光谱辐射
     *
     * @param measSpectralRadiation 光谱辐射
     * @return 结果
     */
    public int updateMeasSpectralRadiation(MeasSpectralRadiation measSpectralRadiation);

    /**
     * 删除光谱辐射
     *
     * @param id 光谱辐射主键
     * @return 结果
     */
    public int deleteMeasSpectralRadiationById(Long id);

    /**
     * 批量删除光谱辐射
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMeasSpectralRadiationByIds(Long[] ids);

    MeasSpectralRadiation selectResultsByEnvDataId(Long envDataId);
}
